<h1>BIGlibrary</h1>
<p>A package with many functions that are repeated with developers or that help improve software performance or facilitate programming.</p>

[![Python package](https://github.com/yasserbdj96/biglibrary/actions/workflows/python-app.yml/badge.svg?branch=main)](https://github.com/yasserbdj96/biglibrary/actions/workflows/python-app.yml) [![CodeFactor](https://www.codefactor.io/repository/github/yasserbdj96/biglibrary/badge)](https://www.codefactor.io/repository/github/yasserbdj96/biglibrary) [![Visitors](https://visitor-badge.laobi.icu/badge?page_id=yasserbdj96.biglibrary)](https://github.com/yasserbdj96/biglibrary)

<h2>Languages:</h2>
* python3<br>

<h2>Supported Distributions:</h2>

| Distribution     | Version Check | Python Test Version       | Supported | Status    | Everything works |
| :--------------: | :-----------: | :-----------------------: | :-------: | :-------: | :--------------: |
| Ubuntu           | 20.04.4       | 3.6, 3.7, 3.8, 3.9, 3.10  | Yes       | Working   | Yes              |
| Windwos          | 10.0.20348    | 3.6, 3.7, 3.8, 3.9, 3.10  | Yes       | Working   | Yes              |
| MacOS            | 11.6.6        | 3.6, 3.7, 3.8, 3.9, 3.10  | Yes       | Working   | Yes              |
| Android (termux) | 10            | 3.6, 3.7, 3.8, 3.9, 3.10  | Yes       | Working   | Yes              |

<h2>Python Package Installation:</h2>

```
pip install biglibrary
```

<h2>Usage:</h2>

```python
from biglibrary import *

bl=biglibrary()
```

<h2>Examples:</h2>

```python
#START{
from biglibrary import *

# string:
str="hello world!"

# list:
lslist=['orange','pear','kiwi','apple','banana','strawberry','watermelon','pineapple']

# :
bl=biglibrary()# Default returning=False, False for print, True for return.

# Placing text in the middle of the command line interface:
bl.center(str)

# Arrange list and items according to the length of the command line interface:
bl.lslist(lslist,separator=" | ")# Default separator=" | ".
#}END.
```

<h2>Screenshot:</h2>

<div align="center">
    <a href="https://raw.githubusercontent.com/yasserbdj96/biglibrary/main/screenshot/screenshot_center.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/biglibrary/main/screenshot/screenshot_center.png" alt="biglibrary by yasserbdj96">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/biglibrary/main/screenshot/screenshot_lslist.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/biglibrary/main/screenshot/screenshot_lslist.png" alt="biglibrary by yasserbdj96">
    </a>
</div>

<h2>Changelog History:</h2>

```
## 2.0.0 [10-08-2022]
 - New build.
 - More stability.
 - Bug fixes & performance improvements.

## 1.0.1
 - Fix bugs.

## 1.0.0
 - First public release.
```

<h1></h1> 



Don't forget to star ⭐ this repository
<br>

all posts [`#yasserbdj96`](#yasserbdj96) ,all views my own.

<br>
<div align="center">
    <a href="http://yasserbdj96.github.io/">Go to this link to get more information.</a>
</div>